BatchScrapeResult class

Result from a single URL in a batch scrape operation.

Constructors

BatchScrapeResult({required String url, ScrapeResult? result, String? error})
const

Properties

error String?
The error message, if the scrape failed.
final
hashCode int
The hash code for this object.
no setteroverride
result ScrapeResult?
The scrape result, if successful.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
The URL that was scraped.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override