LinkType enum

The classification of a link.

Inheritance
Available extensions

Values

internal → const LinkType

A link to the same domain.

external_ → const LinkType

A link to a different domain.

anchor → const LinkType

A fragment-only link (e.g., #section).

document → const LinkType

A link to a downloadable document (PDF, DOC, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireValue String

Available on LinkType, provided by the LinkTypeWireValue extension

The exact serde wire value for this variant.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LinkType>
A constant List of the values in this enum, in order of their declaration.