ArticleMetadata class
Article metadata extracted from article:* Open Graph tags.
Constructors
Properties
-
The article author.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- modifiedTime → String?
-
The article modification time.
final
- publishedTime → String?
-
The article publication time.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- section → String?
-
The article section.
final
-
The article tags.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override