InteractionResult class
Result of executing a sequence of page interaction actions.
Constructors
-
InteractionResult({required List<
ActionResult> actionResults, required String finalHtml, required String finalUrl, String? screenshotBase64}) -
const
Properties
-
actionResults
→ List<
ActionResult> -
Results from each executed action.
final
- finalHtml → String
-
Final page HTML after all actions completed.
final
- finalUrl → String
-
Final page URL (may have changed due to navigation).
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshotBase64 → String?
-
Base64-encoded PNG screenshot taken after all actions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override